summaryrefslogtreecommitdiffstats
path: root/main.c
diff options
context:
space:
mode:
authorGravatar Linus Torvalds <torvalds@linux-foundation.org>2011-08-31 11:52:16 -0700
committerGravatar Linus Torvalds <torvalds@linux-foundation.org>2011-08-31 11:52:16 -0700
commit7017d17562fe803946ef9e0d8e9af9611bc43ba5 (patch)
tree8d071959402e0bdd8d124d8ab2a5744668efbbd3 /main.c
parent6cc122f491ca9a069dbd226b9fe7529dbcf61058 (diff)
downloadsubsurface-7017d17562fe803946ef9e0d8e9af9611bc43ba5.tar.gz
Use a gtk table instead of hbox
We'll want to add various dive statistics, so... Without them, it all looks pretty much the same, though. Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
Diffstat (limited to 'main.c')
-rw-r--r--main.c17
1 files changed, 9 insertions, 8 deletions
diff --git a/main.c b/main.c
index af1348986..2df31c4d2 100644
--- a/main.c
+++ b/main.c
@@ -59,7 +59,7 @@ int main(int argc, char **argv)
int i;
GtkWidget *win;
GtkWidget *divelist;
- GtkWidget *vbox;
+ GtkWidget *table;
GtkWidget *frame;
parse_xml_init();
@@ -81,19 +81,20 @@ int main(int argc, char **argv)
win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
g_signal_connect(G_OBJECT(win), "destroy", G_CALLBACK(on_destroy), NULL);
- /* HBOX for the list of dives and cairo window */
- vbox=gtk_hbox_new(FALSE, 5);
- gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
- gtk_container_add(GTK_CONTAINER(win), vbox);
- gtk_widget_show(vbox);
+ /* Table for the list of dives, cairo window, and dive info */
+ table = gtk_table_new(2, 2, FALSE);
+ gtk_container_set_border_width(GTK_CONTAINER(table), 5);
+ gtk_container_add(GTK_CONTAINER(win), table);
+ gtk_widget_show(table);
/* Create the atual divelist */
divelist = create_dive_list();
- gtk_container_add(GTK_CONTAINER(vbox), divelist);
+ gtk_table_attach_defaults(GTK_TABLE(table), divelist, 0, 1, 0, 2);
/* Frame for dive profile */
frame = dive_profile_frame();
- gtk_container_add(GTK_CONTAINER(vbox), frame);
+ gtk_table_attach_defaults(GTK_TABLE(table), frame, 1, 2, 1, 2);
+
dive_profile = frame;
gtk_widget_set_app_paintable(win, TRUE);